@@ -58,6 +58,8 @@
 #include "settingswindow.h"
 #include "pluginsettings.h"
 #include "recentdialog.h"
+#include "pluginloaderthread.h"
+
 
 const QDBusArgument & operator<<(QDBusArgument &arg, const Property &change)
 {
@@ -143,6 +145,17 @@ MaemoBarcodeWindow::MaemoBarcodeWindow(QWidget *parent)
     qDebug() << "MainWindow::MainWindow(): Finished setting video widget attributes";
     //    videoWidget->setMinimumSize(300, 200);
 
+    ////videoWidget->setMinimumSize(640,400);
+
+
+    if(settings->value("continous_scanning").toBool()){
+        videoWidget->setContinuousScanning(true);
+        this->continuousScanningMode = true;
+    }else{
+        videoWidget->setContinuousScanning(false);
+        this->continuousScanningMode = false;
+    }
+
     // connect the signal from the barcode decoder
     qDebug() << "MainWindow::MainWindow(): Connecting signals";
     connect(decoder, SIGNAL(imageAnalysed(QString, QString, QImage*)),
@@ -167,6 +180,9 @@ MaemoBarcodeWindow::MaemoBarcodeWindow(QWidget *parent)
     qDebug() << "MainWindow::MainWindow(): Setting central widget";
     this->setCentralWidget(videoWidget);
     qDebug() << "MainWindow::MainWindow(): Finished";
+
+    pluginloaderthread = new PluginLoaderThread(this);
+    pluginloaderthread->run();
 }
 
 MaemoBarcodeWindow::~MaemoBarcodeWindow() {
@@ -237,8 +253,14 @@ void MaemoBarcodeWindow::cameraButtonPropertyModified(int num_updates, QList<Pro
                 QDBusConnection::systemBus());
     bool buttonPressed = propertyInterface.call("GetProperty", "button.state.value").arguments().at(0).toBool();
     qDebug() << "MaemoBarcodeWindow::cameraButtonPropertyModified(: is" << buttonPressed;
-    if(buttonPressed) {
-        saveBufferImage();
+    if(this->continuousScanningMode==true){
+        if(buttonPressed) {
+            saveBufferImage();
+        }
+    }else{
+        if(buttonPressed) {
+            this->videoWidget->startTimedScan(this->videoWidget->timedScanInterval);
+        }
     }
 }
 
@@ -276,62 +298,63 @@ void MaemoBarcodeWindow::ensurePluginsLoaded()
 {
     if (!pluginsLoaded)
     {
-        loadPlugins();
-        pluginsLoaded = true;
+        //loadPlugins();
+        pluginloaderthread->wait();
+        //pluginsLoaded = true;
     }
 }
 
-void MaemoBarcodeWindow::loadPlugins() {
-    // TODO: Create a system which lets the user enable/disable plugins. These should not be loaded.
-
-    qDebug("Loading plugins...");
-
-    //    pluginsDir = QDir(qApp->applicationDirPath());.
-    QDir pluginsDir = QDir("/usr/share/mbarcode/");
-    QDir pluginsDirHome = QDir(QDir::homePath() + "/.config/mbarcode/plugins");
-
-    // some path stuff derived from Nokia's plugin tutorials - not really necessary in a Maemo app, but we'll just leave them here
-#if defined(Q_OS_WIN)
-    if (pluginsDir.dirName().toLower() == "debug" || pluginsDir.dirName().toLower() == "release")
-        pluginsDir.cdUp();
-#elif defined(Q_OS_MAC)
-    if (pluginsDir.dirName() == "MacOS") {
-        pluginsDir.cdUp();
-        pluginsDir.cdUp();
-        pluginsDir.cdUp();
-    }
-#endif
-    pluginsDir.cd("plugins");
-    QStringList allPluginFiles;
-
-    foreach (QString fileName, pluginsDir.entryList(QDir::Files)) { // go through all files in the plugin dir
-        allPluginFiles << pluginsDir.absoluteFilePath(fileName);
-    }
-    foreach (QString fileName, pluginsDirHome.entryList(QDir::Files)) { // go through all files in the plugin dir in home
-        allPluginFiles << pluginsDirHome.absoluteFilePath(fileName);
-    }
-    foreach (QString fileName, allPluginFiles) { // go through all files in the plugin dir
-        qDebug(qPrintable("Loading " + fileName));
-        QPluginLoader loader(fileName); // create a loader for the shared library
-        QObject *plugin = loader.instance();  // load it as a QObject
-        if (plugin) { // if it is a plugin (this fails if virtual functions are not implemented correct)
-            qDebug(qPrintable("Loaded successfully: " + fileName));
-            pluginFileNames += fileName; // list all our plugin file names
-            PluginInterface* interface = qobject_cast<PluginInterface*>(plugin); // cast it to our kind of interface
-            qDebug(qPrintable("Interface name: " + interface->getName()));
-            pluginInterfaces.append(interface); // add this interface to our list of interfaces
-            interface->initInterface(this); // initialize the plugin
-            foreach(PluginAction* pluginAction, interface->getPluginActions()) { // get the list of sink plugins in the interface
-                qDebug(qPrintable("Loading sink plugin " + pluginAction->getName()));
-                pluginActions.append(pluginAction); // add them to our list
-            }
-        } else {
-            qWarning(qPrintable("Could not load: " + fileName));
-        }
-    }
-    qDebug("Done loading plugins");
-    resultsWindow->setPluginActions(pluginActions); // let the resultwindow have all our plugins
-}
+//void MaemoBarcodeWindow::loadPlugins() {
+//    // TODO: Create a system which lets the user enable/disable plugins. These should not be loaded.
+//
+//    qDebug("Loading plugins...");
+//
+//    //    pluginsDir = QDir(qApp->applicationDirPath());.
+//    QDir pluginsDir = QDir("/usr/share/mbarcode/");
+//    QDir pluginsDirHome = QDir(QDir::homePath() + "/.config/mbarcode/plugins");
+//
+//    // some path stuff derived from Nokia's plugin tutorials - not really necessary in a Maemo app, but we'll just leave them here
+//#if defined(Q_OS_WIN)
+//    if (pluginsDir.dirName().toLower() == "debug" || pluginsDir.dirName().toLower() == "release")
+//        pluginsDir.cdUp();
+//#elif defined(Q_OS_MAC)
+//    if (pluginsDir.dirName() == "MacOS") {
+//        pluginsDir.cdUp();
+//        pluginsDir.cdUp();
+//        pluginsDir.cdUp();
+//    }
+//#endif
+//    pluginsDir.cd("plugins");
+//    QStringList allPluginFiles;
+//
+//    foreach (QString fileName, pluginsDir.entryList(QDir::Files)) { // go through all files in the plugin dir
+//        allPluginFiles << pluginsDir.absoluteFilePath(fileName);
+//    }
+//    foreach (QString fileName, pluginsDirHome.entryList(QDir::Files)) { // go through all files in the plugin dir in home
+//        allPluginFiles << pluginsDirHome.absoluteFilePath(fileName);
+//    }
+//    foreach (QString fileName, allPluginFiles) { // go through all files in the plugin dir
+//        qDebug(qPrintable("Loading " + fileName));
+//        QPluginLoader loader(fileName); // create a loader for the shared library
+//        QObject *plugin = loader.instance();  // load it as a QObject
+//        if (plugin) { // if it is a plugin (this fails if virtual functions are not implemented correct)
+//            qDebug(qPrintable("Loaded successfully: " + fileName));
+//            pluginFileNames += fileName; // list all our plugin file names
+//            PluginInterface* interface = qobject_cast<PluginInterface*>(plugin); // cast it to our kind of interface
+//            qDebug(qPrintable("Interface name: " + interface->getName()));
+//            pluginInterfaces.append(interface); // add this interface to our list of interfaces
+//            interface->initInterface(this); // initialize the plugin
+//            foreach(PluginAction* pluginAction, interface->getPluginActions()) { // get the list of sink plugins in the interface
+//                qDebug(qPrintable("Loading sink plugin " + pluginAction->getName()));
+//                pluginActions.append(pluginAction); // add them to our list
+//            }
+//        } else {
+//            qWarning(qPrintable("Could not load: " + fileName));
+//        }
+//    }
+//    qDebug("Done loading plugins");
+//    resultsWindow->setPluginActions(pluginActions); // let the resultwindow have all our plugins
+//}
 
 //void MaemoBarcodeWindow::on_btnScan_clicked()
 //{
