@@ -79,25 +79,33 @@ void ResultsWindow::processBarcode(QString barcode) {
         ui->lblResults->setText(tr("Results for '%1'").arg(barcode));
     }
 
+    checkPlugins();
+
     // save the barcode text
     this->barcode_text = QString(barcode);
-    checkTimer->start(500); // check for updated plugins every x milliseconds
+    checkTimer->start(1000); // check for updated plugins every x milliseconds
 }
 void ResultsWindow::checkPlugins() {
 //    qDebug() << "Checking plugins";
+    bool addedNewPlugins=false;
+
     foreach(PluginAction* plugin, plugins) {
 //        qDebug() << "Checking action plugin " << plugin->getName() << "is ready" << plugin->isReady();
         if(plugin->isReady() && !addedPlugins.contains(plugin)) { // check if it's ready and that it has not yet been added
+            addedNewPlugins=true;
             addedPlugins.append(plugin); // add it to the list of added plugins, so we don't add it twice
 //            qDebug() << "Added plugin" << plugin->getText() << plugin->getName();
         }
     }
-    QAbstractItemModel *oldModel = ui->tblResults->model();
-    PluginActionListModel *model = new PluginActionListModel(this, addedPlugins);
-    ui->tblResults->setModel(model);
-    delete(oldModel);
-    ui->tblResults->resizeRowsToContents();
-    ui->tblResults->setFixedHeight(ui->tblResults->verticalHeader()->length() + 60); // fix to make all contents of scrollwidget scroll together
+
+    if(addedNewPlugins==true){
+        QAbstractItemModel *oldModel = ui->tblResults->model();
+        PluginActionListModel *model = new PluginActionListModel(this, addedPlugins);
+        ui->tblResults->setModel(model);
+        delete(oldModel);
+        ui->tblResults->resizeRowsToContents();
+        ui->tblResults->setFixedHeight(ui->tblResults->verticalHeader()->length() + 60); // fix to make all contents of scrollwidget scroll together
+    }
 }
 
 void ResultsWindow::on_pushButton_clicked()
@@ -162,5 +170,7 @@ QVariant PluginActionListModel::data(const QModelIndex &index, int role) const {
 void ResultsWindow::on_tblResults_clicked(QModelIndex index)
 {
     PluginAction *plugin = qVariantValue<PluginAction*>(index.data());
+    // really need to show the use some visual indication here that they have pressed a "button"
+    // I've no clue how to do this yet though....
     plugin->clickAction(this);
 }
