@@ -46,6 +46,7 @@
 
 #include <QFileDialog>
 #include <QFileInfo>
+#include <QMaemo5InformationBox>
 
 // local includes
 #include "common.h"
@@ -86,11 +87,17 @@ VideoWidget::VideoWidget(MaemoBarcodeWindow *parent, BarcodeDetector *decoder) :
     qDebug() << "VideoWidget::VideoWidget(): Pipeline initialized";
     this->decoder = decoder; // create a new decoder object
 
+
     continuousFocusInterval = 3000;
     refocusTimer = new QTimer(this);
     connect(refocusTimer, SIGNAL(timeout()), this, SLOT(refocus()));
     refocusTimer->setInterval(continuousFocusInterval);
 
+    timedScanInterval = 3000; // should let the user change this in the settings window
+    timedScanTimer = new QTimer(this);
+    connect(timedScanTimer, SIGNAL(timeout()), this, SLOT(stopTimedScan()));
+    timedScanTimer->setInterval(timedScanInterval);
+
     qDebug() << "VideoWidget::VideoWidget(): Setting up images";
     // set up GUI stuff
     imgExit = QImage(":/images/gui/cross.png");
@@ -869,3 +876,36 @@ void VideoWidget::mousePressEvent(QMouseEvent *event){
     }
 }
 
+void VideoWidget::startTimedScan(int time)
+{
+    // enable scanning in the decoder class
+    setContinuousScanning(true);
+
+    // add some sort of graphical notification so people know we're scanning
+
+    // we show this for the same length of time as the scanning goes on, but in fact we should explicitly turn it off in stopTimedScan()
+    // I also don't want an information box, but this will do the job for the time being
+    // Cylon-style plip along the "line up here" line would be better :)
+    QMaemo5InformationBox::information (this->parent, "Scanning...", timedScanInterval);
+
+    // start out timer
+    timedScanTimer->start(time);
+}
+
+void VideoWidget::stopTimedScan()
+{
+    // disable the timer (does this automatically occur anyway?)
+    timedScanTimer->stop();
+    // disable scanning in the decoder thread
+    setContinuousScanning(false);
+
+    // remove graphical notification that we're scanning
+}
+
+void VideoWidget::setContinuousScanning(bool on)
+{
+    if (on==true)
+        decoder->scanning_status=true;
+    else
+        decoder->scanning_status=false;
+}
